@@ -2,13 +2,7 @@ import pytest
 
 
 class TestDd:
-    @pytest.mark.complete(
-        "dd --",
-        xfail=(
-            "! dd --help &>/dev/null || "
-            "! dd --help 2>&1 | command grep -qF -- --help"
-        ),
-    )
+    @pytest.mark.complete("dd --", require_longopt=True)
     def test_1(self, completion):
         assert completion
 
