@@ -9,10 +9,7 @@ class TestGetent:
     @pytest.mark.complete(
         "getent -",
         require_cmd=True,
-        xfail=(
-            "! (getent --help 2>&1 || :) | "
-            "command grep -q -- '[[:space:]]-'"
-        ),
+        xfail="! (getent --help 2>&1 || :) | command grep -q -- '[[:space:]]-'",
     )
     def test_2(self, completion):
         assert completion
